# Supported Providers and Models

This page lists the supported providers and their available models.

## OpenAI
- GPT-3.5 Turbo
- GPT-4
- GPT-4 Turbo

## Google
- Gemini Pro
- Gemini 1.5 Pro

## Anthropic
- Claude 2
- Claude 3 Opus
- Claude 3 Sonnet
- Claude 3 Haiku

## MoonshotAI
- Moonshot-v1-8k
- Moonshot-v1-32k

## Groq
- Llama-3-8b-8192
- Llama-3-70b-8192

<!-- Removed links to model_info.py files for all providers to avoid broken references. -->
